==> haskell-semirings-0.7-65-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semirings
version:              0.7
visibility:           public
id:                   semirings-0.7-9hG4yoSaqtFDoN5AlFr7wu
key:                  semirings-0.7-9hG4yoSaqtFDoN5AlFr7wu
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  b705b4e49cb38ffc04c61a63d5416c59
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Ring.Ordered Data.Semiring
    Data.Semiring.Directed Data.Semiring.Generic Data.Semiring.Tropical
    Data.Star

import-dirs:          /usr/lib/ghc-9.6.6/site-local/semirings-0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/semirings-0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/semirings-0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.7-9hG4yoSaqtFDoN5AlFr7wu
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semirings-0.7-66-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semirings
version:              0.7
visibility:           public
id:                   semirings-0.7-xO3CpBW7PjEZdBzbXCFuJ
key:                  semirings-0.7-xO3CpBW7PjEZdBzbXCFuJ
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  216aaf514c097d4241aef375c9199011
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Ring.Ordered Data.Semiring
    Data.Semiring.Directed Data.Semiring.Generic Data.Semiring.Tropical
    Data.Star

import-dirs:          /usr/lib/ghc-9.6.6/site-local/semirings-0.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/semirings-0.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/semirings-0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.7-xO3CpBW7PjEZdBzbXCFuJ
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
